# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"gdown_unzip": "02_video2picture.ipynb",
         "pose_dis": "00_utils.ipynb",
         "waypoint": "00_utils.ipynb",
         "camera_projection": "01_camera_projection.ipynb",
         "get_images_from_video": "02_video2picture.ipynb",
         "robot_model_loader": "03_robot_model.ipynb",
         "whoami": "04_get_ip.ipynb",
         "get_key": "04_get_ip.ipynb",
         "get_xbee_address": "04_get_ip.ipynb",
         "get_xbee_address_boat": "04_get_ip.ipynb",
         "find_duckiepond_devices_yaml": "04_get_ip.ipynb"}

modules = ["utils.py",
           "camera_projection.py",
           "video2picture.py",
           "robot_model.py",
           "get_ip.py"]

doc_url = "https://ARG-NCTU.github.io/arg_robotics_tools/"

git_url = "https://github.com/ARG-NCTU/arg_robotics_tools/tree/master/"

def custom_doc_links(name): return None



# AUTOGENERATED! DO NOT EDIT! File to edit: 04_get_ip.ipynb (unless otherwise specified).

__all__ = ['whoami', 'get_key', 'get_xbee_address', 'get_xbee_address_boat', 'find_duckiepond_devices_yaml']

# Cell
import subprocess
import os

def whoami(data):

    ret_byte = subprocess.check_output(['ifconfig'])
    ret_str = ret_byte.decode('utf-8')
    # Cut string from 'equal symbol' to 'degree C symbol', then convert to float
    en = ret_str[ret_str.find('eno1:'): ret_str.find('lo')]
    ip = en[en.find('inet')+5: en.find('netmask')-2]
    machine,device = get_key(data,ip)
    return machine,device

def get_key(dict,value):

    for k, v in dict.items():
        for v,v1 in v.items():
            for v1,v2 in v1.items():
                if v2 == value:
                    return k,v

def get_xbee_address(dict,value):
    for k, v in dict.items():
        for v,v1 in v.items():
            for v1,v2 in v1.items():
                if v2 == value:
                    address = dict[k]["rpi"]['xbee_rx']
                    return address

def get_xbee_address_boat(dict,value):
    pair_device = dict[value]["xbee"]["xbee_pair"]
    address = dict[pair_device]["rpi_2"]["xbee_rx"]
    return address

def find_duckiepond_devices_yaml(yaml_filename="duckiepond-devices.yaml"):
    dp_yaml_path = ""
    for root, dirs, files in os.walk(os.path.expanduser('~')):
        for name in files:
            if name == yaml_filename:
                dp_yaml_path = os.path.abspath(os.path.join(root, name))
                break
    return dp_yaml_path
